# Chapter 6, Figure 6.5 - ANOVA example 1 (within-subjects using data in anova-ex1.txt)

# Reminder: before running this script in RStudio, set the working directory
# to the location of the source file and data file:
#
#    Session --> Set Working Directory --> To Source File Location

# fresh start
cat("\f") # clear console
rm(list = ls(all.names = TRUE)) # clear environment

# load the data ...

# option 1 - read data from file 
data1 = read.delim("anova-ex1.txt", header=FALSE, sep="", 
  col.names = c("A", "B"))

# option 2 - include data in script
# data1 = data.frame(A=c(5.3, 3.6, 5.2, 3.5, 4.6, 4.1, 4.0, 4.8, 5.2, 5.1),
#     B=c(5.7, 4.8, 5.1, 4.5, 6.0, 6.8, 6.0, 4.6, 5.5, 5.6))

# show the data
data1

# reorganize into "long" format
data2 = reshape(data1, direction="long", varying=c("A","B"), v.names="Time",
                timevar = "Condition", idvar="Participant")

# add column for levels of within-subjects factor
data2$Method = rep(c("A", "B"), each=10)

# show reorganized data
data2

# do the ANOVA (within-subjects, 1 factor)
result = aov(Time ~ Method + Error(factor(Participant)), data = data2)

# show the ANOVA table (cf. Figure 6.5)
summary(result)

# *** end ***
