# Chapter 6, Figure 6.8 - ANOVA example 2 (within-subjects using data in anova-ex2.txt)

# Reminder: before running this script in RStudio, set the working directory
# to the location of the source file and data file:
#
#    Session --> Set Working Directory --> To Source File Location

# fresh start
cat("\f") # clear console
rm(list = ls(all.names = TRUE)) # clear environment

# load the data ...

# option 1 - read data from file
data1 = read.delim("anova-ex2.txt", header=FALSE, sep="",
  col.names = c("A", "B"))

# option 2 - include data in script
# data1 = data.frame(A=c(2.4, 2.7, 3.4, 6.1, 6.4, 5.4, 7.9, 1.2, 3, 6.6),
#     B=c(6.9, 7.2, 2.6, 1.8, 7.8, 9.2, 4.4, 6.6, 4.8, 3.1))

# show the data
data1

# reorganize into "long" format
data2 = reshape(data1, direction="long", varying=c("A","B"), v.names="Time",
                timevar = "Condition", idvar="Participant")

# add column for levels of within-subjects factor
data2$Method = rep(c("A", "B"), each=10)

# show reorganized data
data2

# do the ANOVA (within-subjects, 1 factor)
result = aov(Time ~ Method + Error(factor(Participant)), data = data2)

# show ANOVA table (cf. Figure 6.8)
summary(result)

# *** end ***
