# Chapter 6, Figure 6.18b - Dix example

# Reminder: before running this script in RStudio, set the working directory
# to the location of the source file and data file:
#
#    Session --> Set Working Directory --> To Source File Location

# fresh start
cat("\f") # clear console
rm(list = ls(all.names = TRUE)) # clear environment

# load the data ...

# option 1 - read data from file
data1 = read.delim("dix-example-10x2.txt", header=FALSE, sep=",", 
  col.names = c("Natural", "Abstract"))

# option 2 - include data in script
#data1 = data.frame(Natural=c(656, 259, 612, 609, 1049, 1135, 542, 495, 905, 715),
#    Abstract=c(702, 339, 658, 645, 1129, 1179, 604, 551, 893, 803))

# show the data
data1

# reorganize into "long" format, as per R style
data2 = reshape(data1, direction="long", varying=c("Natural","Abstract"), 
                v.names="Time", timevar="Condition", idvar="Participant")

# add column for levels of within-subjects factor
data2$Icon_Type = rep(c("Natural", "Abstract"), each=10)

# show reorganized data
data2

# do the ANOVA 
result = aov(Time ~ Icon_Type + Error(factor(Participant)), data = data2)

# show the ANOVA table (cf. Figure 6.18c)
summary(result)

# *** end ***
