# Chapter 6, Figure 6.20 - two-factor mixed design, testing for a group effect

# This is a re-analysis of the data in dix-example-ex1.txt with an additional column for "group"

# Reminder: before running this script in RStudio, set the working directory
# to the location of the source file and data file:
#
#    Session --> Set Working Directory --> To Source File Location

# fresh start
cat("\f") # clear console
rm(list = ls(all.names = TRUE)) # clear environment

# load the data ...

# option 1 - read data from file (adjust path as per local computer)
data1 = read.delim("dix-example-h10x2b.txt", header=FALSE, sep=",", 
  skip=8, na="", col.names = c("Natural", "Abstract", "Group"))

# option 2 - include data in script
# data1 = data.frame(Natural=c(656, 259, 612, 609, 1049, 1135, 542, 495, 905, 715),
#      Abstract=c(702, 339, 658, 645, 1129, 1179, 604, 551, 893, 803),
#      Group=c("NA", "NA", "NA", "NA", "NA", "AN", "AN", "AN", "AN", "AN"))

# show the data
data1

# reorganize time data into "long" format
data2 = reshape(data1[1:2], direction="long", varying=c("Natural","Abstract"), 
                v.names="Time", timevar = "Condition", idvar="Participant")

# add column for levels of within-subjects factor, icon_type
data2$Icon_Type = rep(c("Natural", "Abstract"), each=10)

# add column for group
data2 = cbind(data2, data1[3])

# show the data (long format)
data2

# need this library when using anova_test and get_anova_table functions
library(rstatix)

res.aov = anova_test(
   data = data2, 
   dv = Time, 
   wid = Participant,
   within = Icon_Type,
   between = Group,
   detailed=TRUE
)

# show the ANOVA table (cf. Figure 6.20)
get_anova_table(res.aov) 

# *** end ***
