# Chapter 6, Figure 6.42 - Friedman test - example 1

# This script also does post hoc comparisons, as per Figure 6.42b.

# Reminder: before running this script in RStudio, set the working directory
# to the location of the source file and data file:
#
#    Session --> Set Working Directory --> To Source File Location

# fresh start
cat("\f") # clear console
rm(list = ls(all.names = TRUE)) # clear environment

# load the data ...

# option 1 - read data from file
data1 = read.delim("friedman-ex1.txt", header=FALSE, sep="")

# option 2 - include data in script (in long format)
# data1 = data.frame(V1=c(66, 79, 67, 71, 72, 68, 71, 74),
#   V2=c(80, 64, 58, 73, 66, 67, 68, 69),
#   V3=c(67, 61, 61, 54, 59, 57, 59, 69),
#   V4=c(73, 66, 67, 75, 78, 69, 64, 66))

# show data
data1

# reorganize into "long" format
data2 = reshape(data1,
  direction="long",
  varying=c("V1", "V2", "V3", "V4"),
  v.names="Quality_of_Results")

# add column for search interface
data2$Search_Interface = rep(c("A", "B", "C", "D"), each=8)

# show the data
data2

# do the Friedman test, show result (cf. Figure 6.42)
friedman.test(y=data2$Quality_of_Results, 
  groups=data2$Search_Interface,
  blocks=data2$id)

# --------------------------------
# now, do the post hoc comparisons
# --------------------------------

# do the pairwise comparisons, show result (cf. Figure 6.42b, but see note below)
pairwise.wilcox.test(data2$Quality_of_Results, 
  data2$Search_Interface,
  p.adjust.method="BH")

# NOTE: The pairwise comparisons above use a different method than used by 
# GoStats.  However, the result is the same: the difference is significant
# (p < .05) only for pairs 1:3 (A:C) and 3:4 (C:D).

# *** end ***
