# Chapter 6, Figure 6.40 - Kruskal-Wallis test using data in kruskalwallis-ex1.txt

# This script also does post hoc comparisons consistent with Figure 6.40b.

# Reminder: before running this script in RStudio, set the working directory
# to the location of the source file and data file:
#
#    Session --> Set Working Directory --> To Source File Location

# fresh start
cat("\f") # clear console
rm(list = ls(all.names = TRUE)) # clear environment

# load the data ...

# option 1 - read data from file
data1 = read.delim("kruskalwallis-ex1.txt", header=FALSE, sep="",
            col.names = c("A20_29", "A30_39", "A40_49"))

# option 2 - include data in script
# data1 = data.frame(A20_29=c(9, 9, 4, 9, 6, 3, 8, 9), 
#                     A30_39=c(7, 3, 5, 3, 2, 1, 4, 7), 
#                     A40_49=c(4, 5, 5, 2, 2, 1, 2, 2))

# show the data
data1

# reorganize into "long" format
data2 = reshape(data1, 
   direction="long", 
   varying=c("A20_29","A30_39","A40_49"), 
   timevar="Age_Group",
   v.names="Acceptability_Score")

data2

# change column "id" name to "Participant"
colnames(data2)[3] = "Participant"

# add column for Age Group with appropriate labels
data2$Age_Group = rep(c("A20_29", "A30_39", "A40_49"), each=8)

# show the data
data2

# do the Kruskal-Wallis test
result = kruskal.test(Acceptability_Score ~ Age_Group, data = data2)

# show result (cf. Figure 6.40)
result

# -------------------------------
# now do the post hoc comparisons
# -------------------------------

# do post hoc comparisons, show result (cf. Figure 6.40b, but see note below)
pairwise.wilcox.test(data2$Acceptability_Score, 
    data2$Age_Group, 
    p.adjust.method = "bonferroni")

# NOTE: The pairwise comparisons above use a different method than used by 
# GoStats.  However, the result is the same: the difference is significant 
# (p < .05) only for the 1:3 pair (i.e., A20_29 vs. # A40_49).

# *** end ***
