# Chapter 6, Figure 6.33 - Lilliefors test for normality - example 3

# Reminder: before running this script in RStudio, set the working directory
# to the location of the source file and data file:
#
#    Session --> Set Working Directory --> To Source File Location

# fresh start
cat("\f") # clear console
rm(list = ls(all.names = TRUE)) # clear environment

# load the data from file
data1 = read.delim("lilliefors-ex3.txt", header=FALSE, sep=",", comment="#")

# need this library to run the lillie.test function
library(nortest)

# do the Lilliefors test over all the data sets
nSets = nrow(data1)
nRejected = 0
s1 = ""
for (i in 1:nSets) {
   sd = sd(data1[i,])
   n = length(data1[i,])
   M = mean(as.numeric(data1[i,]))
   result = lillie.test(t(data1[i,]))
   test_statistic = result[1]
   p =  result[2]
   hypothesis = "NOT_REJECTED"
   if (p < .05) {
      hypothesis = "REJECTED"
      nRejected = nRejected + 1
   }
   s1 = paste(s1, sprintf('%2d: n=%3d, mean=%6.2f, sd=%5.2f, D=%.5f, p-value=%.4f, %s\n', i, n, M, sd, test_statistic, p, hypothesis))
}
s2 = sprintf('Data_sets=%d, Null_hypothesis: Rejected=%d, Not_rejected=%d\n', nSets, nRejected, nSets-nRejected)
s3 = paste(s1, s2)

# show output (cf. Table 6.33, but see comment below)
cat(s3)

# NOTE: R's lillie.test function computes the Lilliefors test statistic, D.
# However, it does not compute or output the critical value against which the 
# test statistic is compared.  Instead, it computes the p-value.  Presumably, p 
# is above .05 when the test statistic is below the critical value (meaning the 
# null hypothesis of normality is tenable) and p is below .05 when the test 
# statistic is above the critical value (meaning the null hypothesis of 
# normality can be rejected).

# *** end ***
