# Chapter 6, Figure 6.36 - Mann Whitney U test - example 1

# Reminder: before running this script in RStudio, set the working directory
# to the location of the source file and data file:
#
#    Session --> Set Working Directory --> To Source File Location

# fresh start
cat("\f") # clear console
rm(list = ls(all.names = TRUE)) # clear environment

# load the data ...

# option 1 - read data from file
data1 = read.delim("mannwhitneyu-ex1.txt", header=FALSE, sep="")

# option 2 - include data in script
# data1 = data.frame(V1=c(2, 3, 2, 4, 9, 2, 5, 3, 4, 3),
#     V2=c(4, 6, 5, 4, 8, 3, 4, 2, 4, 5))

# show the data
data1

# reorganize into "long" format
data2 = reshape(data1, 
   direction="long",
   varying=c("V1", "V2"),
   v.names="Assessments");

# add column for type of user
data2$Type_of_User = rep(c("Mac_user", "PC_user"), each=10)

# show data
data2

# do the Mann-Whitney U test (without the correction for continuity)
result = wilcox.test(Assessments ~ Type_of_User, 
   data=data2,
   paired=FALSE,
   exact=FALSE,
   correct=FALSE)

result[6] = "Mann-Whitney U test" # use appropriate label for output

# output result (cf. Figure 6.36, but see note below)
result

# NOTE: R's wilcox.test function, for the Mann-Whitney U test, does not compute 
# or output the z-statistic, as is typical with other statistics applications.  
# However, z can be computed from the p-value.  This is demonstrated below.

p = as.numeric(result[3])/2
z = qnorm(p)
s = sprintf('z = %.3f (corrected for ties)\n', z)
cat(s)

# *** end ***
