# Chapter 6, Figure 6.11 - ANOVA example - more than 2 within-subjects conditions

# This script also does Scheffe post hoc comparisons as in Figure 6.12.

# Reminder: before running this script in RStudio, set the working directory
# to the location of the source file and data file:
#
#    Session --> Set Working Directory --> To Source File Location

# fresh start
cat("\f") # clear console
rm(list = ls(all.names = TRUE)) # clear environment

# load the data ...

# option 1 - read data from file (adjust path as per local computer)
data1 = read.delim("posthoc-ex1.txt", header=FALSE, sep="", 
  col.names = c("A", "B", "C", "D"))

# option 2 - include data in script
# data1 = data.frame(A=c(11, 18, 17, 19, 13, 10, 14, 13, 19, 10, 10, 16, 10, 10, 20, 18),
#     B=c(11, 11, 10, 15, 17, 15, 14, 14, 18, 17, 19, 14, 20, 13, 17, 17),
#     C=c(21, 22, 18, 21, 23, 15, 15, 19, 16, 21, 22, 18, 17, 21, 14, 17),
#     D=c(16, 15, 13, 20, 10, 20, 13, 18, 12, 18, 13, 20, 19, 18, 18, 14)
# )

# show the data
data1

# reorganize into "long" format
data2 = reshape(data1, direction="long", varying=c("A","B","C","D"), 
                v.names="DV", timevar = "Condition", idvar="Participant")

# add column for levels of within-subjects factor
data2$Method = rep(c("A", "B", "C", "D"), each=16)

# show reorganized data
data2

# do the ANOVA (within-subjects, 1 factor)
result = aov(DV ~ Method + Error(factor(Participant)), data = data2)

# view anova table (cf. Figure 6.11)
summary(result)

# -------------------------------
# now do the post hoc comparisons
# -------------------------------

# create a simplified model first
model = aov(DV ~ Method, data=data2)

# need the DescTools library to use PostHocTest function
library(DescTools)

# do post hoc comparisons (cf. Figure 6.12)
PostHocTest(model, which=NULL, "scheffe") 

# *** end ***
