# Chapter 6 - Figure 6.16 - two-way analysis of variance (within-subjects using data in twofactor.txt)

# reference: https://www.datanovia.com/en/lessons/repeated-measures-anova-in-r/#two-way-repeated-measures-anova

# Reminder: before running this script in RStudio, set the working directory
# to the location of the source file and data file:
#
#    Session --> Set Working Directory --> To Source File Location

# fresh start
cat("\f") # clear console
rm(list = ls(all.names = TRUE)) # clear environment

# read the data
data1 = read.delim("twofactor.txt", header=FALSE, sep="")

# show the data
data1

# reorganize into "long" format
data2 = reshape(data1, direction="long", varying=c("V1","V2", "V3", "V4", "V5", "V6"), 
                v.names="Time", timevar = "Condition", idvar="Participant")

# add columns for factors and levels
data2$Input_Method = rep(c("finger", "finger+stylus", "stylus"), each=24)
data2$Task = rep(c(rep(c("pointing", "dragging"), each=12)), times=3)

# optional: for post hos tests, add a column for the combinations of input_method & task ("IMT") 
#data2$IMT = rep(c("fp", "fd", "fsp", "fsd", "sp", "sd"), each=12)

# show the data
data2

# need this library to use anova_test and get_anova_table
library(rstatix)

# do the ANOVA
res.aov = anova_test(
    data = data2, 
    formula = Time ~ Input_Method * Task + Error(Participant/(Input_Method*Task)),
    detailed=TRUE
)

# NOTE: The following syntax also works
# res.aov = anova_test(
#    data = data2, 
#    dv = Time,
#    wid = Participant,
#    within = c(Input_Method, Task),
#    detailed=TRUE
# )

# show the ANOVA table (cf. Figure 6.16)
get_anova_table(res.aov)

# optional: pairwise comparisons for the input_method + task combinations
# pairwise_t_test(data=data2,
#   Time ~ IMT, 
#   paired = TRUE,
#   p.adjust.method = "bonferroni"
# )

# *** end ***
