# Chapter 6, Figure 6.38 - Wilcoxon Signed Ranks test - example 1

# Reminder: before running this script in RStudio, set the working directory
# to the location of the source file and data file:
#
#    Session --> Set Working Directory --> To Source File Location

# fresh start
cat("\f") # clear console
rm(list = ls(all.names = TRUE)) # clear environment

# load the data ...

# option 1 - read data from file
data1 = read.delim("wilcoxonsignedranks-ex1.txt", header=FALSE, sep="")
MPa = as.numeric(unlist(data1[1])) # media player a
MPb = as.numeric(unlist(data1[2])) # media player b

# option 2 - include data in script
# mpa = c(3, 6, 4, 10, 6, 5, 9, 7, 6, 8) # media player A
# mpb = c(3, 6, 3, 3, 5, 6, 2, 4, 2, 3)  # media player B

# do the Wilcoxon Signed Ranks test (without the correction for continuity)
result = wilcox.test(MPa, MPb, 
  paired=TRUE,
  correct=FALSE)

# show the result (cf. Figure 6.38, but see note below)
result

# NOTE: R's wilcox.test function does not compute or output the z-statistic, as 
# is typical with other statistics applications.  However, z can be computed 
# from the p-value.  This is demonstrated below.

p = as.numeric(result[3])/2
z = qnorm(p)
s = sprintf('z = %.3f (corrected for ties)\n', z)
cat(s)

# *** end ***
